@@ -45,7 +45,7 @@ root = E('root', atr=100).add(
        )
 """
 
-__VERSION__ = '0.2b'
+__VERSION__ = '0.3'
 
 from lxml import etree
 
@@ -59,7 +59,7 @@ def SE(elem, _tag, attrib=None, nsmap=None, **_extra):
     
 def _make_elem(_tag, attrib=None, nsmap=None, **_extra):
     for k,v in _extra.items():
-        if isinstance(v, (int, )):
+        if isinstance(v, (int, long, float)):
             v = str(v)
         elif v is None:
             v = ''
@@ -98,7 +98,7 @@ class _E(etree.ElementBase):
         
         for elem in elements:
             
-            if not isinstance(elem, (basestring, int)):
+            if not isinstance(elem, (basestring, int, long, float)):
                 # we have elemettree
                 if prev_elem is not None:
                     # because we have previous elem
@@ -117,11 +117,11 @@ class _E(etree.ElementBase):
             else:
                 # we have some text
                 # so we can store it for later
-                if isinstance(elem, int):
+                if isinstance(elem, (int, long, float)):
                     elem = str(elem)
                 text_elems.append(elem)
         else:
-            if not isinstance(elem, (basestring, int)):
+            if not isinstance(elem, (basestring, int, long, float)):
                 # last element isn't string
                 # so we shoud append it
                 self.append(elem)
